##  Scope and Limitations
The GitHub Enterprise integration helps you discover microservices by placing a YAML manifest file in the root directory of your repository. This integration does not include:
  * Generating Software Bill of Materials (SBOM). For more information on generating SBOMs, refer to [Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the requirements for SBOM files and get an overview of the methods for generating them.").
  * Automated discovery of microservices without placing a YAML manifest file in your repository.
